import type { KeyValueLike } from "../_share.js";
/**
 * GitHub Actions file command type.
 */
export type GitHubActionsFileCommandType = "pairs" | "raw" | "values";
/**
 * **\[🅰️ Advanced\]** Get the file command path in order to communicate with the GitHub Actions runner via the file command.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @returns {string} Path of the file command.
 */
export declare function getFileCommandPath(command: string): string;
/**
 * **\[🅰️ Advanced\]** Append value to the file line command.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @param {...string} values Value of the file line command.
 * @returns {void}
 */
export declare function appendFileLineCommand(command: string, ...values: string[]): void;
/**
 * **\[🅰️ Advanced\]** Append pair to the file map command.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @param {string} key Key of the pair of the file map command.
 * @param {string} value Value of the pair of the file map command.
 * @returns {void}
 */
export declare function appendFileMapCommand(command: string, key: string, value: string): void;
/**
 * **\[🅰️ Advanced\]** Append pairs to the file map command.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @param {KeyValueLike} pairs Pairs of the file map command.
 * @returns {void}
 */
export declare function appendFileMapCommand(command: string, pairs: KeyValueLike): void;
/**
 * **\[🅰️ Advanced\]** Clear the file command which set in the current step.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @returns {void}
 */
export declare function clearFileCommand(command: string): void;
/**
 * **\[🅰️ Advanced\]** Optimize the file command to reduce size whenever possible.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @param {string} command File command.
 * @param {GitHubActionsFileCommandType} [type="raw"] Type of the file command; Only used when the {@linkcode command} is not known.
 * @returns {void}
 */
export declare function optimizeFileCommand(command: string, type?: GitHubActionsFileCommandType): void;
//# sourceMappingURL=file.d.ts.map