import { type KeyValueLike, type StringizableType } from "./_share.js";
/**
 * Add value to the `PATH`.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_PATH` (Optional)
 * >   - `PATH` (Optional)
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @param {string} path Value that need to add to the `PATH`.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function addPATH(path: string, options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * Add value to the `PATH`.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_PATH` (Optional)
 * >   - `PATH` (Optional)
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @param {string[]} paths Value that need to add to the `PATH`.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function addPATH(paths: string[], options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * **\[🅰️ Advanced\]** Clear the environment variables for all of the subsequent steps which set in the current step.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_ENV`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export declare function clearEnvironmentVariableSubsequent(): void;
export { clearEnvironmentVariableSubsequent as clearEnvSubsequent };
/**
 * **\[🅰️ Advanced\]** Clear the `PATH` for all of the subsequent steps which set in the current step.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_PATH`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @returns {void}
 */
export declare function clearPATHSubsequent(): void;
/**
 * **\[🅰️ Advanced\]** Optimize the environment variables for all of the subsequent steps which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_ENV`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export declare function optimizeEnvironmentVariableSubsequent(): void;
export { optimizeEnvironmentVariableSubsequent as optimizeEnvSubsequent };
/**
 * **\[🅰️ Advanced\]** Optimize the `PATH` for all of the subsequent steps which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_PATH`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @returns {void}
 */
export declare function optimizePATHSubsequent(): void;
export interface GitHubActionsSetEnvironmentVariableOptions {
    /**
     * Whether to set for the current step.
     * @default {true}
     */
    scopeCurrent?: boolean;
    /**
     * Whether to set for all of the subsequent steps.
     * @default {true}
     */
    scopeSubsequent?: boolean;
}
/**
 * Set an environment variable.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_ENV` (Optional)
 * >   - *Resources* (Optional)
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @param {string} key Key of the environment variable.
 * @param {StringizableType} value Value of the environment variable.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function setEnvironmentVariable(key: string, value: StringizableType, options?: GitHubActionsSetEnvironmentVariableOptions): void;
/**
 * Set the environment variables.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_ENV` (Optional)
 * >   - *Resources* (Optional)
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources* (Optional)
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources* (Optional)
 * @param {KeyValueLike<StringizableType>} pairs Pairs of the environment variable.
 * @param {GitHubActionsSetEnvironmentVariableOptions} [options={}] Options.
 * @returns {void}
 */
export declare function setEnvironmentVariable(pairs: KeyValueLike<StringizableType>, options?: GitHubActionsSetEnvironmentVariableOptions): void;
export { setEnvironmentVariable as setEnv };
//# sourceMappingURL=environment_variable.d.ts.map