/**
 * Make secret get masked from the log.
 * @param {...string} values Secret that need to get masked from the log.
 * @returns {void}
 */
export declare function addSecretMask(...values: string[]): void;
export { addSecretMask as addMask, addSecretMask as addSecret };
/**
 * Create a foldable group in the log; Anything write to the log are inside this foldable group in the log.
 * @param {string} [title=""] Title of the foldable group.
 * @returns {void}
 */
export declare function enterLogGroup(title?: string): void;
export { enterLogGroup as startLogGroup };
/**
 * End an foldable group in the log.
 * @returns {void}
 */
export declare function exitLogGroup(): void;
export { exitLogGroup as endLogGroup };
/**
 * GitHub Actions annotation type.
 */
export type GitHubActionsAnnotationType = "error" | "notice" | "warning";
/**
 * GitHub Actions annotation properties.
 */
export interface GitHubActionsAnnotationProperties {
    /**
     * Path of the issue file of the annotation.
     */
    file?: string;
    /**
     * Line start of the issue file of the annotation.
     */
    line?: number;
    /**
     * Column start of the issue file of the annotation.
     */
    column?: number;
    /**
     * Line end of the issue file of the annotation.
     */
    lineEnd?: number;
    /**
     * Column end of the issue file of the annotation.
     */
    columnEnd?: number;
    /**
     * Title of the annotation.
     */
    title?: string;
    /**
     * Summary of the annotation when the message is too large to display.
     */
    summary?: string;
}
/**
 * Print an annotation to the log.
 * @param {GitHubActionsAnnotationType} type Type of the annotation.
 * @param {string} data Data of the annotation.
 * @param {GitHubActionsAnnotationProperties} [properties={}] Properties of the annotation.
 * @returns {void}
 */
export declare function writeAnnotation(type: GitHubActionsAnnotationType, data: string, properties?: GitHubActionsAnnotationProperties): void;
/**
 * Print a debug message to the log.
 * @param {...string} data Data that need to log at debug level.
 * @returns {void}
 */
export declare function writeDebug(...data: string[]): void;
/**
 * Print an error annotation to the log.
 * @param {string} data Data of the annotation.
 * @param {GitHubActionsAnnotationProperties} [properties={}] Properties of the annotation.
 * @returns {void}
 */
export declare function writeError(data: string, properties?: GitHubActionsAnnotationProperties): void;
/**
 * Print a notice annotation to the log.
 * @param {string} data Data of the annotation.
 * @param {GitHubActionsAnnotationProperties} [properties={}] Properties of the annotation.
 * @returns {void}
 */
export declare function writeNotice(data: string, properties?: GitHubActionsAnnotationProperties): void;
export { writeNotice as writeNote };
/**
 * Print a warning annotation to the log.
 * @param {string} data Data of the annotation.
 * @param {GitHubActionsAnnotationProperties} [properties={}] Properties of the annotation.
 * @returns {void}
 */
export declare function writeWarning(data: string, properties?: GitHubActionsAnnotationProperties): void;
export { writeWarning as writeWarn };
//# sourceMappingURL=log.d.ts.map